#delimit;
clear all;
capture log close;
set more off;
set mem 500m;
set linesize 255;

use EtAlData;


*********************;
** Variable Creation;
*********************;

* Author Count Dummies;
qui tab authn  if (authn<=5), gen(aDum);
drop aDum1;
label var aDum2 "Two Authors";
label var aDum3 "Three Authors";
label var aDum4 "Four Authors";
label var aDum5 "Five Authors";
gen dateLin = (date-15000);
gen dateSq = (date-15000)^2;

* NEW DV: DRAFT HAS 2+ REVISIONS;
gen rev1 = (ttlVer > 1 | (ttlVer == 1 & rfcDum));
gen rev2 = (ttlVer > 2 | (ttlVer <= 2 & rfcDum));
label var rev2 "Two+ revisions";

* RFC Stock/Count Dummies;
g noRfcs = (rfcstock==0);
g rfcCnt1 = (rfcstock==1);
g rfcCnt2 = (rfcstock==2);
g rfcCnt3 = (rfcstock==3|rfcstock==4);
g rfcCnt4 = (rfcstock>4 & rfcstock<=10);
g rfcCnt5 = (rfcstock>10);

g year = year(date);


*********************;
** Start of Analysis ;
*********************;


** TABLE 2: DESCRIPTIVE STATISTICS;
log using tables/table2.log, t replace;
tabstat rfcDum wglists mentions ttlVer rev1 anyUnlist anyChair treat_wgcd rfcstock noRfcs rfcCnt1-rfcCnt5 
	 authn logpages intl multi lndaysb4conf threads authemail year if indId == 1, format(%9.3f) stat(mean sd n) col(stat);
	 
tabstat rfcDum wglists mentions ttlVer rev1 anyUnlist anyChair treat_wgcd rfcstock noRfcs rfcCnt1-rfcCnt5 
	 authn logpages intl multi lndaysb4conf threads authemail year if wgId == 1, format(%9.3f) stat(mean sd n) col(stat);
log close;


** TABLE 3: STATUS AND SIGNALING;
quietly {;
	reg rfcDum anyChair treat_wgcd anyUnlist if indId == 1, r;
	est store col1;
	estadd ysumm;

	reg rfcDum anyChair treat_wgcd rfcCnt* anyUnlist logpages intl multi lndaysb4conf aDum2-aDum5 i.date2 if indId == 1, r;
	est store col2;
	estadd ysumm;
	testparm anyChair rfcCnt*;
	estadd scalar joint_pval = r(p);

	reg rfcDum anyChair treat_wgcd anyUnlist if wgId == 1, r;
	est store col3;
	estadd ysumm;

	reg rfcDum anyChair treat_wgcd rfcCnt* anyUnlist logpages intl multi lndaysb4conf aDum2-aDum5 i.date2 if wgId == 1, r;
	est store col4;
	estadd ysumm;
	testparm anyChair rfcCnt*;
	estadd scalar joint_pval = r(p);
};

log using tables/table3.log, t replace;
estout _all, cells(b(star fmt(3)) se(par fmt(2))) stats(N r2 ymean joint_pval, fmt(0 2 2 2)) drop(aDum* 1*) starlevels(+ 0.10 * 0.05 ** 0.01) label margin style(tex);
log close;
est clear;


** TABLE 4: STATUS, ATTENTION & PERSISTENCE;
quietly {; 
	* Independent ID regressions;
	reg wglist anyChair treat_wgcd anyUnlist logpages intl multi lndaysb4conf authemail aDum2-aDum5 i.date2 if indId == 1, r;
	estadd ysumm;
	est store col1;

	reg mentions anyChair treat_wgcd anyUnlist logpages intl multi lndaysb4conf authemail aDum2-aDum5 i.date2 if indId == 1, r;
	estadd ysumm;
	est store col2;

	reg rev1 anyChair treat_wgcd anyUnlist logpages intl multi lndaysb4conf authemail aDum2-aDum5 i.date2 if indId == 1, r;
	estadd ysumm;
	est store col3;

	* WG ID regressions;
	reg wglist anyChair treat_wgcd anyUnlist logpages intl multi lndaysb4conf authemail aDum2-aDum5 i.date2 if wgId == 1, r;
	estadd ysumm;
	est store col4;

	reg mentions anyChair treat_wgcd anyUnlist logpages intl multi lndaysb4conf authemail aDum2-aDum5 i.date2 if wgId == 1, r;
	estadd ysumm;
	est store col5;
	
	reg rev1 anyChair treat_wgcd anyUnlist logpages intl multi lndaysb4conf authemail aDum2-aDum5 i.date2 if wgId == 1, r;
	estadd ysumm;
	est store col6;	
};

log using tables/table4.log, t replace;
estout _all, cells(b(star fmt(3)) se(par fmt(2))) stats(N r2 ymean, fmt(0 3 3)) drop(aDum* 1*) starlevels(+ 0.10 * 0.05 ** 0.01) style(tex);
log close;
est clear;


*********************;
** APPENDIX TABLES **;
*********************;
** EXOGENEITY OLS;
quietly{;
	reg anyUnlist anyChair lname multi intl logpages lndaysb4conf aDum3-aDum5 dateLin dateSq if indId==1 & authn>=2, r;
	est store col1;
	test anyChair lname multi intl logpages;
	estadd scalar joint_pval = r(p);

	reg anyUnlist anyChair rfcCnt* lname multi intl logpages lndaysb4conf aDum3-aDum5 dateLin dateSq if indId==1 & authn>=2, r;
	est store col2;
	testparm rfcCnt*;
	estadd scalar rfcCnt_pval = r(p);
	test anyChair rfcCnt1 rfcCnt2 rfcCnt3 rfcCnt4 rfcCnt5 lname multi intl logpages ;
	estadd scalar joint_pval = r(p);

	reg anyUnlist anyChair lname multi intl logpages lndaysb4conf aDum3-aDum5 dateLin dateSq if wgId==1 & authn>=2, r;
	est store col3;
	test anyChair lname multi intl logpages;
	estadd scalar joint_pval = r(p);

	reg anyUnlist anyChair rfcCnt* lname multi intl logpages lndaysb4conf aDum3-aDum5 dateLin dateSq if wgId==1 & authn>=2, r;
	est store col4;
	testparm rfcCnt*;
	estadd scalar rfcCnt_pval = r(p);
	test anyChair rfcCnt1 rfcCnt2 rfcCnt3 rfcCnt4 rfcCnt5 lname multi intl logpages ;
	estadd scalar joint_pval = r(p);
};

log using tables/tableA1_ols.log, t replace;
estout _all, cells(b(star fmt(3)) se(par fmt(2))) stats(N ll rfcCnt_pval joint_pval, fmt(0 1 2 2)) starlevels(+ 0.10 * 0.05 ** 0.01) label margin style(tex);
log close;
est clear;


** EXOGENEITY LOGITS;
quietly{;
	logit anyUnlist anyChair lname multi intl logpages lndaysb4conf aDum3-aDum5 dateLin dateSq if indId==1 & authn>=2, r;
	mfx;
	est store col1;
	test anyChair lname multi intl logpages;
	estadd scalar joint_pval = r(p);
	
	logit anyUnlist anyChair rfcCnt* lname multi intl logpages lndaysb4conf aDum3-aDum5 dateLin dateSq if indId==1 & authn>=2, r;
	qui mfx;
	est store col2;
	testparm rfcCnt*;
	estadd scalar rfcCnt_pval = r(p);
	test anyChair rfcCnt1 rfcCnt2 rfcCnt3 rfcCnt4 rfcCnt5 lname multi intl logpages ;
	estadd scalar joint_pval = r(p);
	
	logit anyUnlist anyChair lname multi intl logpages lndaysb4conf aDum3-aDum5 dateLin dateSq if wgId==1 & authn>=2, r;
	qui mfx;
	est store col3;
	test anyChair lname multi intl logpages;
	estadd scalar joint_pval = r(p);

	logit anyUnlist anyChair rfcCnt* lname multi intl logpages lndaysb4conf aDum3-aDum5 dateLin dateSq if wgId==1 & authn>=2, r;
	qui mfx;
	est store col4;
	testparm rfcCnt*;
	estadd scalar rfcCnt_pval = r(p);
	test anyChair rfcCnt1 rfcCnt2 rfcCnt3 rfcCnt4 rfcCnt5 lname multi intl logpages ;
	estadd scalar joint_pval = r(p);
};

log using tables/tableA1.log, t replace;
estout _all, cells(b(star fmt(3)) se(par fmt(2))) stats(N ll rfcCnt_pval joint_pval, fmt(0 1 2 2)) starlevels(+ 0.10 * 0.05 ** 0.01) label margin style(tex);
log close;
est clear;


** STATUS & "REPUTATION";
quietly {;
	reg anyChair noRfc rfcCnt* aDum2-aDum5 i.date2 if (indId == 1), r nocons;
	estadd ysumm;
	est store col1;
	reg anyChair noRfc rfcCnt* i.date2 if (indId == 1 & authn == 1), r nocons;
	estadd ysumm;
	est store col2;
};

log using tables/tableA2.log, t replace;
estout _all, cells(b(star fmt(3)) se(par fmt(2))) stats(N r2 ymean, fmt(0 2 2)) drop(1*) starlevels(+ 0.10 * 0.05 ** 0.01) label margin style(tex);
log close;
est clear;


* TABLE A3: MAIN ROBUSTNESS CHECKS;
gen cpos = max(lwgcpos, ulwgcpos);
qui tab cpos if indId == 1 & authn>1 & leadwgc==0, g(cposd);
qui tab ulwgcpos if indId == 1, g(ulcd);
qui tab lwgcpos if indId==1, gen(lcd);
drop cposd1 ulcd1;

label var ulcd2 "Unlisted Chair2";
label var ulcd3 "Unlisted Chair3";
label var ulcd4 "Unlisted Chair4";
label var ulcd5 "Unlisted Chair5";
label var cposd2 "Chair2";
label var cposd3 "Chair3";

g treat_undoc = etal_undoc * treat_wgcd;
label var treat_undoc "Undoc EtAl * Chair";
label var etal_undoc "Undocumented EtAl";

quietly {;
	** Baseline;
	logit rfcDum anyChair treat_wgcd anyUnlist if indId == 1, r;
	mfx;
	est store col1;	
	** Undocumented EtAls;
	reg rfcDum anyChair treat_wgcd treat_undoc anyUnlist etal_undoc rfcCnt* logpages intl multi lndaysb4conf aDum2-aDum5 i.date2 if indId == 1, r;
	test treat_undoc etal_undoc;
	est store col2;
	** Effect by Position;
	reg rfcDum anyChair ulcd* anyUnlist rfcCnt* logpages intl multi lndaysb4conf aDum2-aDum5 i.date2 if indId == 1, r;
	testparm ulcd*;
	estadd scalar joint_p = r(p);
	est store col3;
	** Auths>1;
	reg rfcDum anyChair treat_wgcd anyUnlist rfcCnt* logpages intl multi lndaysb4conf aDum2-aDum5 i.date2 if (indId == 1 & authn>1), r;
	est store col4;
	** 2 Author No Lead Chair;
	reg rfcDum anyChair treat_wgcd anyUnlist rfcCnt* logpages intl multi lndaysb4conf i.date2 if indId == 1 & (authn==2) & leadwgc == 0, r;
	est store col5;
};

log using tables/tableA3.log, t replace;
estout _all, cells(b(star fmt(3)) se(par fmt(2))) stats(N r2 ll joint_p, fmt(0 2 1 2)) drop(aDum* 1* rfcCnt*) order(anyChair treat_wgcd anyUnlist treat_undoc etal_undoc ulcd* logpages intl multi lndaysb4conf) starlevels(+ 0.10 * 0.05 ** 0.01) label margin style(tex);
log close;
est clear;


* TABLE A4: Attention Robustness Checks;
quietly {;
	* Individual ID regressions;
	poisson wglist anyChair treat_wgcd anyUnlist rfcCnt* logpages intl multi lndaysb4conf authemail aDum2-aDum5 i.date2 if indId == 1, r;
	est store col1;
	testparm anyChair rfcCnt*;
	estadd scalar joint_p = r(p);

	poisson mentions anyChair treat_wgcd anyUnlist rfcCnt* logpages intl multi lndaysb4conf authemail aDum2-aDum5 i.date2 if indId == 1, r;
	est store col2;
	testparm anyChair rfcCnt*;
	estadd scalar joint_p = r(p);

	logit rev1 anyChair treat_wgcd anyUnlist rfcCnt* logpages intl multi lndaysb4conf authemail aDum2-aDum5 date if indId == 1, r;
	mfx;
	est store col3;
	testparm anyChair rfcCnt*;
	estadd scalar joint_p = r(p);

	* WG ID regressions;
	poisson wglist anyChair treat_wgcd anyUnlist rfcCnt* logpages intl multi lndaysb4conf authemail aDum2-aDum5 i.date2 if wgId == 1, r;
	est store col4;
	testparm anyChair rfcCnt*;
	estadd scalar joint_p = r(p);
	
	poisson mentions anyChair treat_wgcd anyUnlist rfcCnt* logpages intl multi lndaysb4conf authemail aDum2-aDum5 i.date2 if wgId == 1, r;
	est store col5;
	testparm anyChair rfcCnt*;
	estadd scalar joint_p = r(p);
	
	logit rev1 anyChair treat_wgcd anyUnlist rfcCnt* logpages intl multi lndaysb4conf authemail aDum2-aDum5 date if wgId == 1, r;
	mfx;
	est store col6;
	testparm anyChair rfcCnt*;
	estadd scalar joint_p = r(p);
};

log using tables/tableA4.log, t replace;
estout _all, cells(b(star fmt(3)) se(par fmt(2))) stats(N ll joint_p, fmt(0 1 2 )) drop(1* aDum* rfcCnt*) starlevels(+ 0.10 * 0.05 ** 0.01) margin style(tex);
log close;
est clear;


**********************************;
**           FIGURES            **;
**********************************;
* FIGURE 1: IETF Process;
* FIGURE 2: examples of announce messages/headers/footers;
* case 1: chairs listed;
* draft-wakikawa-nemo-basic-00.txt;
* case 2: chairs unlisted + etal;
* draft-barnes-midcom-mib-01.txt;
* case 3: chairs unlisted + undoc etal;
* draft-ash-e2e-vompls-hdr-compress-01.txt;

set scheme s2mono;

* FIGURE 3: EtAl and Meeting Dates;
twoway lowess anyUnlist date if year > 1997 & year < 2005 & authn>2,
  bwidth(0.05) xline(14695 14555 14436 14317 14219, lsty(major_grid)) xline(14822 14954 15052 15318 15416 15661 15780, lsty(major_grid))
  xline(14695 15192 15535 15899 16018, lsty(major_grid))  xline(13967 14114 16383 16284 16129, lsty(major_grid)) ytitle("Et Al Probability") 
  xtitle("") ylabel(,nogrid) tlab(,format(%tdmY))
;
graph save date_etal1, replace;
graph export figures/etal1.pdf, replace;


* FIGURE 4: Etal and Submission Volume;
twoway kdensity date if year > 1997 & year < 2005 & authn>2, width(15) yaxis(1) ytitle("Density", axis(1)) xtitle("") ||
   lowess anyUnlist date if year > 1997 & year < 2005 & authn>2, bwidth(0.05) yaxis(2) 
   ytitle("Et Al Probability", axis(2)) xtitle("") legend(lab(1 "ID Submissions") lab(2 "Et Al Probability")) ylabel(,nogrid) tlab(,format(%tdmY));
graph save date_etal2, replace;
graph export figures/etal2.pdf, replace;

